@@ -18,11 +18,11 @@ p.startup()
 w=wacc.Wacc()
 w.startup()
 b=base.Base()
-b.startup()
+b.startup(threaded=False)
 a=arm.Arm()
-a.startup()
+a.startup(threaded=False)
 l=lift.Lift()
-l.startup()
+l.startup(threaded=False)
 print('Version: stretch_body: %s'%stretch_body.__version__)
 print('---------- Boards ----------')
 print('Pimu:            %s'%p.board_info['board_version'])
